@@ -3,41 +3,48 @@
 Description:
 ------------
 
-A Configuration consists of one or several sections. Each ConfigurationSection consists of one or more entries. Each
-ConfigurationEntry consists of a key and a value.
+A Configuration consists of one or several sections. Each ConfigurationSection
+consists of one or more entries. Each ConfigurationEntry consists of a key and
+a value.
 
 
 Examples:
 ---------
 
-For basic use, an entry is looked up by simple attribute access. For instance if `cfg` is a Configuration with the
-section `midgard` which has an entry `foo = bar`:
+For basic use, an entry is looked up by simple attribute access. For instance
+if `cfg` is a Configuration with the section `midgard` which has an entry `foo
+= bar`:
 
+    >>> cfg = Configuration("config_name")
+    >>> cfg.update("midgard", "foo", "bar")
     >>> cfg.midgard.foo
-    ConfigurationEntry('foo', 'bar')
+    ConfigurationEntry(key='foo', value='bar')
 
-ConfigurationEntry has several access methods that convert the entry to a given data type:
+ConfigurationEntry has several access methods that convert the entry to a given
+data type:
 
+    >>> cfg.update("midgard", "foo_pi", 3.14, source="command line")
     >>> cfg.midgard.foo_pi
-    ConfigurationEntry('foo_pi', '3.14')
+    ConfigurationEntry(key='foo_pi', value='3.14')
     >>> cfg.midgard.foo_pi.float
     3.14
     >>> cfg.midgard.foo_pi.str
     '3.14'
     >>> cfg.midgard.foo_pi.tuple
-    ('3.14', )
+    ('3.14',)
 
 
 Sources:
 --------
 
-Each configuration entry records its source. That is, where that entry was defined. Examples include read from file,
-set as a command line option, or programmatically from a dictionary. The source can be looked up on an individual
-entry, or for all entries in a configuration.
+Each configuration entry records its source. That is, where that entry was
+defined. Examples include read from file, set as a command line option, or
+programmatically from a dictionary. The source can be looked up on an
+individual entry, or for all entries in a configuration.
 
-    >>> cfg.midgard.foo.source
-    '/home/midgard/midgard.conf'
-    >>> cfg.sources
+    >>> cfg.midgard.foo_pi.source
+    'command line'
+    >>> cfg.sources  # doctest: +SKIP
     {'/home/midgard/midgard.conf', 'command line'}
 
 
@@ -45,7 +52,7 @@ Profiles:
 ---------
 
 
-Parent Configuration:
+Fallback Configuration:
 ---------------------
 
 
@@ -60,7 +67,6 @@ Replacement Variables:
 Help text and Type hints:
 -------------------------
 
-
 """
 
 # Standard library imports
@@ -74,20 +80,19 @@ import re
 import sys
 from collections import UserDict
 
-# Where imports
+# Midgard imports
 from midgard.dev import console
 from midgard.collections import enums
 from midgard.dev import exceptions
 
 
 # Typing
-from typing import Any, Callable, Dict, List, Optional, Set, Tuple, Union
+from typing import Any, Callable, Dict, Generator, List, Optional, Set, Tuple, Union
 
-ProfileName = Union[None, str]
-SectionName = str
-Sections = Dict[SectionName, "ConfigurationSection"]
+ProfileName = Optional[str]
+Sections = Dict[str, "ConfigurationSection"]
 EntryName = str
-ConfigVars = Dict[str, Any]
+ConfigVars = Dict[str, str]
 
 
 # Date and datetime formats
@@ -96,7 +101,15 @@ FMT_datetime = "%Y-%m-%d %H:%M:%S"
 FMT_dt_file = "%Y%m%d-%H%M%S"
 
 
-class Configuration():
+class CasedConfigParser(ConfigParser):
+    """ConfigParser with case-sensitive keys"""
+
+    def optionxform(self, optionstr: str) -> str:
+        """Do not turn optionstr (key) into lowercase"""
+        return optionstr
+
+
+class Configuration:
     """Represents a Configuration"""
 
     def __init__(self, name: str) -> None:
@@ -108,7 +121,7 @@ class Configuration():
             name:  Name of configuration.
         """
         self.name = name
-        self.parent_config = None
+        self.fallback_config = None
         self.master_section = None
 
         self._profiles: List[ProfileName] = [None]
@@ -122,6 +135,7 @@ class Configuration():
         """Read a configuration from one or more files
 
         Args:
+            cfg_name:    Name of configuration.
             file_paths:  File(s) that will be read.
 
         Returns:
@@ -135,7 +149,7 @@ class Configuration():
 
     @classmethod
     @contextmanager
-    def update_on_file(cls, file_path: Union[str, pathlib.Path]) -> None:
+    def update_on_file(cls, file_path: Union[str, pathlib.Path], **as_str_args: Any) -> Generator:
         """Context manager for updating a configuration on file
         """
         # Read config from file
@@ -147,30 +161,35 @@ class Configuration():
 
         # Write config if it has been updated
         if cfg._update_count > update_count_before:
-            cfg.write_to_file(file_path)
+            cfg.write_to_file(file_path, **as_str_args)
 
-    def write_to_file(self, file_path: Union[str, pathlib.Path], **as_str_args) -> None:
+    def write_to_file(self, file_path: Union[str, pathlib.Path], **as_str_args: Any) -> None:
         """Write the configuration to a file
 
         In addition to the file path, arguments can be specified and will be passed on to the as_str() function. See
         `as_str()` for more information.
 
         Todo: Use files.open_path
-
         """
+        file_path = pathlib.Path(file_path)
         file_path.parent.mkdir(parents=True, exist_ok=True)
         with open(file_path, mode="w") as fid:
             fid.write(self.as_str(**as_str_args) + "\n")
 
     @property
-    def sections(self) -> List[SectionName]:
-        """List of sections in Configuration"""
+    def section_names(self) -> List[str]:
+        """Names of sections in Configuration"""
         return list(self._sections.keys())
 
+    @property
+    def sections(self) -> List["ConfigurationSection"]:
+        """Sections in Configuration"""
+        return list(self._sections.values())
+
     @property
     def sources(self) -> Set[str]:
         """Sources of entries in Configuration"""
-        return {self[s][k].source for s in self.sections for k in self[s].keys() if self[s][k].source}
+        return {s[k].source for s in self.sections for k in s.keys() if s[k].source}
 
     @property
     def profiles(self) -> List[ProfileName]:
@@ -210,37 +229,35 @@ class Configuration():
                     self._sections[section_name][key] = entry
 
     @property
-    def parent_config(self) -> "Configuration":
-        """The parent configuration"""
-        if self._parent_config is None:
+    def fallback_config(self) -> "Configuration":
+        """The fallback configuration"""
+        if self._fallback_config is None:
             raise exceptions.MissingConfigurationError(
-                f"Configuration '{self.name}' has not defined a parent configuration"
+                f"Configuration '{self.name}' has not defined a fallback configuration"
             )
-        return self._parent_config
+        return self._fallback_config
 
-    @parent_config.setter
-    def parent_config(self, cfg: Optional["Configuration"]) -> None:
-        """Set the parent configuration"""
-        self._parent_config = cfg
+    @fallback_config.setter
+    def fallback_config(self, cfg: Optional["Configuration"]) -> None:
+        """Set the fallback configuration"""
+        self._fallback_config = cfg
 
     @property
     def master_section(self) -> "ConfigurationSection":
         """The master section"""
         if self._master_section is None:
-            raise exceptions.MissingSectionError(f"Configuration '{self.name}' has not defined a master section")
+            raise exceptions.MissingSectionError(f"Configuration {self.name!r} has not defined a master section")
+        if self._master_section not in self._sections:
+            raise exceptions.MissingSectionError(
+                f"Master section {self._master_section!r} does not exist in configuration {self.name!r}"
+            )
 
-        try:
-            return self._sections[self._master_section]
-        except KeyError:
-            return ConfigurationSection("undefined")
+        return self._sections[self._master_section]
 
     @master_section.setter
-    def master_section(self, section: Optional[SectionName]):
+    def master_section(self, section: Optional[str]) -> None:
         """Set the master section"""
-        if section is None or section in self._sections:
-            self._master_section = section
-        else:
-            raise exceptions.MissingSectionError(f"Configuration '{self.name}' does not contain section '{section}'")
+        self._master_section = section
 
     def get(
         self, key: str, value: Optional[str] = None, section: Optional[str] = None, default: Optional[str] = None
@@ -251,7 +268,7 @@ class Configuration():
 
             1. An explicit value given in `value`. None is used as a marker for no value.
             2. Looked up in the current configuration.
-            3. Looked up in any parent confiurations that are defined.
+            3. Looked up in any fallback configurations that are defined.
             4. The default value is used.
 
         If `value` is not None, that value is simply returned as a `ConfigurationEntry`. If `default` is not given (is
@@ -270,19 +287,47 @@ class Configuration():
             return ConfigurationEntry(key, value=value, source="method call", vars_dict=self.vars)
 
         try:
-            return self.master_section[key] if section is None else self[section][key]
-        except (exceptions.MissingSectionError, exceptions.MissingEntryError):
+            section_value = self.master_section if section is None else self[section]
+            if isinstance(section_value, ConfigurationEntry):
+                return section_value
+            else:
+                return section_value[key]
+        except (exceptions.MissingSectionError, exceptions.MissingEntryError) as err:
             try:
-                return self.parent_config.get(key=key, section=section)
+                return self.fallback_config.get(key=key, section=section)
             except (exceptions.MissingConfigurationError, exceptions.MissingEntryError):
                 if default is None:
-                    return self.master_section[key] if section is None else self[section][key]
+                    # Raise original error
+                    raise err
                 else:
                     return ConfigurationEntry(key, value=default, source="default value", vars_dict=self.vars)
 
+    def exists(self, key: str, section: Optional[str] = None) -> bool:
+        """Check if a configuration entry exists
+
+        Args:
+            key:      Name of option (key in the configuration entry).
+            section:  Section in the configuration in which to look up the key.
+
+        Returns:
+            True if the configuration entry exists, otherwise False.
+        """
+        if section is None:
+            return self.master_section.exists(key)
+
+        try:
+            cfg_section = self[section]
+        except (exceptions.MissingSectionError, exceptions.MissingEntryError):
+            return False
+
+        if isinstance(cfg_section, ConfigurationEntry):
+            return False
+        else:
+            return cfg_section.exists(key)
+
     def update(
         self,
-        section: SectionName,
+        section: str,
         key: str,
         value: str,
         *,
@@ -339,16 +384,20 @@ class Configuration():
             self._set_sections_for_profiles()
 
     def update_from_file(
-        self, file_path: Union[str, pathlib.Path], allow_new: bool = True, interpolate: bool = False
+        self,
+        file_path: Union[str, pathlib.Path],
+        allow_new: bool = True,
+        interpolate: bool = False,
+        case_sensitive: bool = False,
     ) -> None:
         """Update the configuration from a configuration file
 
         The Python ConfigParser is used to read the file. The file format that is supported is described at
         https://docs.python.org/library/configparser.html
 
-        Different profiles in a configuration file is denoted by double underscores in the sections names. For instance
-        does the following configuration have a `foo` profile in the `spam` section (in addition to the default
-        profile):
+        Different profiles in a configuration file are denoted by double underscores in the sections names. For
+        instance will the following configuration have a `foo` profile in the `spam` section (in addition to the
+        default profile):
 
             [spam]
             ...
@@ -356,26 +405,43 @@ class Configuration():
             [spam__foo]
             ...
 
-        If `interpolate` is set to True, ExtendedInterpolation of variables in the configuration file is used. See
+        The file may contain a special section called `__replace__` which may contain key-value pairs which will
+        replace format-style strings in keys and values in the rest of the file.
+
+        Additionally, the file may contain a special section called `__vars__`. The key-value pairs from this section
+        will be added to the `dictionary` of the configuration.
+
+        If `interpolate` is set to True, ExtendedInterpolation of variables in the configuration file is used. This
+        means that variables of the form ${key:section} can be used for references within the file. See
         https://docs.python.org/library/configparser.html#configparser.ExtendedInterpolation for details.
 
         Args:
-            file_path:    Path to the configuration file.
-            allow_new:    Whether to allow the creation of new sections and entries.
-            interpolate:  Whether to interpolate variables in the configuration file.
+            file_path:      Path to the configuration file.
+            allow_new:      Whether to allow the creation of new sections and entries.
+            interpolate:    Whether to interpolate variables in the configuration file.
+            case_sensitive: Whether to read keys as case sensitive (or convert to lower case).
         """
         # Use ConfigParser to read from file
-        cfg_parser_args = dict(
+        cfg_parser_cls = CasedConfigParser if case_sensitive else ConfigParser
+        cfg_parser = cfg_parser_cls(
             allow_no_value=True,
             delimiters=("=",),
             interpolation=ExtendedInterpolation() if interpolate else BasicInterpolation(),
         )
-        cfg_parser = ConfigParser(**cfg_parser_args)
         cfg_parser.read(file_path)
 
+        # Read special __replace__
+        replace_vars = {k: v for k, v in cfg_parser["__replace__"].items()} if "__replace__" in cfg_parser else {}
+
+        # Add __vars__ to vars dictionary
+        if "__vars__" in cfg_parser.sections():
+            self.update_vars({k: v for k, v in cfg_parser["__vars__"].items()})
+
         # Add configuration entries
         for cfg_section in cfg_parser.sections():
             section, has_profile, profile = cfg_section.partition("__")
+            if not section:  # Skip dunder sections
+                continue
             for key, value in cfg_parser[cfg_section].items():
                 # Handle meta-information
                 if ":" in key:
@@ -385,8 +451,8 @@ class Configuration():
                 # Create a configuration entry
                 self.update(
                     section,
-                    key,
-                    value if value is None else value.replace("\n", " "),
+                    _replace(key, replace_vars),
+                    value if value is None else _replace(value, replace_vars).replace("\n", " "),
                     profile=profile if has_profile else None,
                     source=str(file_path),
                     meta=meta,
@@ -397,11 +463,19 @@ class Configuration():
         self._set_sections_for_profiles()
 
     def update_from_config_section(
-        self, other_section: "ConfigurationSection", section: Optional[SectionName] = None, allow_new: bool = True
+        self, other_section: "ConfigurationSection", section: Optional[str] = None, allow_new: bool = True
     ) -> None:
         section = other_section.name if section is None else section
-        for key, entry in other_section.items():
-            self.update(section, key, entry.str, source=entry.source, meta=entry.meta, allow_new=allow_new, _update_sections=False)
+        for key, entry in other_section.data.items():
+            self.update(
+                section,
+                key,
+                entry.str,
+                source=entry.source,
+                meta=entry.meta,
+                allow_new=allow_new,
+                _update_sections=False,
+            )
 
         self._set_sections_for_profiles()
 
@@ -415,6 +489,7 @@ class Configuration():
         if options is None:
             options = sys.argv[1:]
 
+        updated_options = set()
         for option in options:
             if not (option.startswith("--") and "=" in option):
                 continue
@@ -429,22 +504,27 @@ class Configuration():
                 continue
             if not opt_section:
                 opt_section = self.master_section.name
-            self.update(
-                opt_section,
-                opt_key,
-                opt_value,
-                profile=profile,
-                source=f"{source} ({option})",
-                allow_new=allow_new,
-                _update_sections=False,
-            )
+            try:
+                self.update(
+                    opt_section,
+                    opt_key,
+                    opt_value,
+                    profile=profile,
+                    source=f"{source} ({option})",
+                    allow_new=allow_new,
+                    _update_sections=False,
+                )
+                updated_options.add(option)
+            except exceptions.MissingEntryError:
+                pass
 
         self._set_sections_for_profiles()
+        return list(set(options) - updated_options)
 
     def update_from_dict(
         self,
         cfg_dict: Dict[str, Any],
-        section: Optional[SectionName] = None,
+        section: Optional[str] = None,
         source: str = "dictionary",
         allow_new: bool = True,
     ) -> None:
@@ -497,8 +577,8 @@ class Configuration():
         return "\n\n\n".join(s for s in section_strs if s)
 
     def as_dict(
-        self, getters: Optional[Dict[SectionName, Dict[str, str]]] = None, default_getter: str = "str"
-    ) -> Dict[SectionName, Dict[str, Any]]:
+        self, getters: Optional[Dict[str, Dict[str, str]]] = None, default_getter: str = "str"
+    ) -> Dict[str, Dict[str, Any]]:
         """The configuration represented as a dictionary
 
         Args:
@@ -511,34 +591,37 @@ class Configuration():
         getters = dict() if getters is None else getters
         return {k: v.as_dict(getters=getters.get(k), default_getter=default_getter) for k, v in self._sections.items()}
 
-    def __getitem__(self, key: SectionName) -> "ConfigurationSection":
+    def __getitem__(self, key: str) -> Union["ConfigurationSection", "ConfigurationEntry"]:
         """Get a section or entry from the master section from the configuration"""
-        try:
+        if key in self.section_names:
             return self._sections[key]
-        except KeyError:
-            try:
-                return self.master_section[key]
-            except exceptions.MissingSectionError:
-                raise exceptions.MissingSectionError(f"Configuration '{self.name}' has no section '{key}'") from None
 
-    def __getattr__(self, key: SectionName) -> "ConfigurationSection":
+        try:
+            return self.master_section[key]
+        except exceptions.MissingSectionError:
+            try:
+                return self.fallback_config[key]
+            except exceptions.MidgardException:
+                raise exceptions.MissingSectionError(f"Configuration {self.name!r} has no section {key!r}") from None
+
+    def __getattr__(self, key: str) -> Union["ConfigurationSection", "ConfigurationEntry"]:
         """Get a section or entry from the master section from the configuration"""
         return self[key]
 
-    def __delitem__(self, key: SectionName) -> None:
+    def __delitem__(self, key: str) -> None:
         """Delete a section from the configuration"""
         del self._sections[key]
 
-    def __delattr__(self, key: SectionName) -> None:
+    def __delattr__(self, key: str) -> None:
         """Delete a section from the configuration"""
         del self._sections[key]
 
     def __dir__(self) -> List[str]:
         """List attributes and sections in the configuration"""
         try:
-            return super().__dir__() + self.sections + self.master_section.as_list()
+            return list(super().__dir__()) + self.section_names + self.master_section.as_list()
         except exceptions.MissingSectionError:
-            return super().__dir__() + self.sections
+            return list(super().__dir__()) + self.section_names
 
     def __str__(self) -> str:
         """The configuration represented as a string
@@ -554,9 +637,11 @@ class Configuration():
 
 class ConfigurationSection(UserDict):
 
-    def __init__(self, name: SectionName) -> None:
+    data: Dict[str, "ConfigurationEntry"]
+
+    def __init__(self, name: str) -> None:
         super().__init__()
-        self.name = name
+        self.name: str = name
 
     def as_str(
         self, width: Optional[int] = None, key_width: int = 30, only_used: bool = False, metadata: bool = True
@@ -607,14 +692,25 @@ class ConfigurationSection(UserDict):
         getters = {k: getters.get(k, default_getter) for k in self.keys()}
         return {k: getattr(e, getters[k]) for k, e in self.items()}
 
-    def __getitem__(self, key: EntryName) -> "ConfigurationEntry":
+    def exists(self, key: str) -> bool:
+        """Check if key exists in section
+
+        Args:
+            key:  Name of configuration key.
+
+        Returns:
+            True if key is in section, False otherwise.
+        """
+        return key in self.data
+
+    def __getitem__(self, key: str) -> "ConfigurationEntry":
         """Get an entry from the configuration section"""
         try:
             return self.data[key]
         except KeyError:
             raise exceptions.MissingEntryError(f"Configuration section '{self.name}' has no entry '{key}'") from None
 
-    def __getattr__(self, key: EntryName) -> "ConfigurationEntry":
+    def __getattr__(self, key: str) -> "ConfigurationEntry":
         """Get an entry from the configuration section"""
         try:
             return self.data[key]
@@ -623,7 +719,7 @@ class ConfigurationSection(UserDict):
 
     def __dir__(self) -> List[str]:
         """List attributes and entries in the configuration section"""
-        return super().__dir__() + self.as_list()
+        return list(super().__dir__()) + self.as_list()
 
     def __str__(self) -> str:
         """The configuration section represented as a string"""
@@ -634,19 +730,26 @@ class ConfigurationSection(UserDict):
         return f"{self.__class__.__name__}(name='{self.name}')"
 
 
-class ConfigurationEntry():
+class ConfigurationEntry:
 
     _BOOLEAN_STATES = {
-        "0": False, "1": True, "false": False, "true": True, "no": False, "yes": True, "off": False, "on": True
+        "0": False,
+        "1": True,
+        "false": False,
+        "true": True,
+        "no": False,
+        "yes": True,
+        "off": False,
+        "on": True,
     }
 
     def __init__(
         self,
-        key: EntryName,
+        key: str,
         value: Any,
         *,
         source: builtins.str = "",
-        meta: Optional[Dict[str, Any]] = None,
+        meta: Optional[Dict[str, str]] = None,
         vars_dict: Optional[ConfigVars] = None,
         _used_as: Optional[Set[builtins.str]] = None,
     ) -> None:
@@ -792,7 +895,9 @@ class ConfigurationEntry():
         self._using("list")
         return self._value.replace(",", " ").split()
 
-    def as_list(self, split_re: builtins.str = r"[\s,]", convert: Callable = builtins.str) -> List[Any]:
+    def as_list(
+        self, split_re: builtins.str = r"[\s,]", convert: Callable = builtins.str, maxsplit: builtins.int = 0
+    ) -> List[Any]:
         """Value of ConfigurationEntry converted to a list
 
         The entry is converted to a list by using the `split_re`-regular expression. By default the entry will be split
@@ -801,12 +906,13 @@ class ConfigurationEntry():
         Args:
             split_re:  Regular expression used to split entry into list.
             convert:   Function used to convert each element of the list.
+            maxsplit:  If nonzero, at most maxsplit splits occur.
 
         Returns:
             Value of entry as list.
         """
         self._using("list")
-        return [convert(s) for s in re.split(split_re, self._value) if s]
+        return [convert(s) for s in re.split(split_re, self._value, maxsplit=maxsplit) if s]
 
     @property
     def list_of_lists(self) -> List[List[builtins.str]]:
@@ -828,7 +934,9 @@ class ConfigurationEntry():
         self._using("tuple")
         return tuple(self._value.replace(",", " ").split())
 
-    def as_tuple(self, split_re: builtins.str = r"[\s,]", convert: Callable = builtins.str) -> Tuple[Any, ...]:
+    def as_tuple(
+        self, split_re: builtins.str = r"[\s,]", convert: Callable = builtins.str, maxsplit: builtins.int = 0
+    ) -> Tuple[Any, ...]:
         """Value of ConfigurationEntry converted to a tuple
 
         The entry is converted to a tuple by using the `split_re`-regular expression. By default the entry will be
@@ -837,24 +945,26 @@ class ConfigurationEntry():
         Args:
             split_re:  Regular expression used to split entry into tuple.
             convert:   Function used to convert each element of the tuple.
+            maxsplit:  If nonzero, at most maxsplit splits occur.
 
         Returns:
             Value of entry as tuple.
         """
         self._using("tuple")
-        return tuple([convert(s) for s in re.split(split_re, self._value) if s])
+        return tuple([convert(s) for s in re.split(split_re, self._value, maxsplit=maxsplit) if s])
 
     @property
     def dict(self) -> Dict[builtins.str, builtins.str]:
         """Value of ConfigurationEntry converted to a dict"""
         self._using("dict")
-        return dict(i.split(":", maxsplit=1) for i in self.list)
+        return dict(i.partition(":")[::2] for i in self.list)
 
     def as_dict(
         self,
         item_split_re: builtins.str = r"[\s,]",
         key_value_split_re: builtins.str = r"[:]",
         convert: Callable = builtins.str,
+        maxsplit: builtins.int = 0,
     ) -> Dict[builtins.str, Any]:
         """Value of ConfigurationEntry converted to a dictionary
 
@@ -865,12 +975,13 @@ class ConfigurationEntry():
             item_split_re:       Regular expression used to split entry into items.
             key_value_split_re:  Regular expression used to split items into keys and values.
             convert:             Function used to convert each value in the dictionary.
+            maxsplit:            If nonzero, at most maxsplit splits occur when splitting entry into items.
 
         Returns:
             Value of entry as dict.
         """
         self._using("dict")
-        items = [s for s in re.split(item_split_re, self._value) if s]
+        items = [s for s in re.split(item_split_re, self._value, maxsplit=maxsplit) if s]
         key_values = [re.split(key_value_split_re, i, maxsplit=1) for i in items]
         return {k: convert(v) for k, v in key_values}
 
@@ -892,23 +1003,8 @@ class ConfigurationEntry():
         return self.replace()
 
     def replace(self, default: Optional[builtins.str] = None, **replace_vars: builtins.str) -> "ConfigurationEntry":
-        replacement_vars = dict(self._vars_dict, **replace_vars)
-        replacement_value = self._value
-        replacements = list()
-
-        matches = re.findall(r"\{\$\w+\}", replacement_value)
-        for match in matches:
-            var = match.strip("${}")
-            replacement = str(replacement_vars.get(var, match if default is None else default))
-            replacements.append(f"{var}={replacement}")
-            replacement_value = replacement_value.replace(match, replacement)
-
-        return self.__class__(
-            key=self._key,
-            value=replacement_value,
-            source=self.source + " ({','.join(replacements)})",
-            _used_as=self._used_as,
-        )
+        value = _replace(self._value, dict(self._vars_dict, **replace_vars), default)
+        return self.__class__(key=self._key, value=value, source=self.source, _used_as=self._used_as)
 
     @property
     def is_used(self) -> builtins.bool:
@@ -978,3 +1074,36 @@ class ConfigurationEntry():
     def __repr__(self) -> builtins.str:
         """A simple string representation of the configuration entry"""
         return f"{self.__class__.__name__}(key='{self._key}', value='{self._value}')"
+
+
+def _replace(string: str, replace_vars: Dict[str, str], default: Optional[str] = None) -> str:
+    """Replace format style variables in a string
+
+    Handles nested replacements by first replacing the replace_vars. Format specifiers (after colon, :) are allowed,
+    but can not contain nested format strings.
+
+    This function is used instead of str.format for three reasons. It handles:
+
+    - that not all pairs of {...} are replaced at once
+    - optional default values for variables that are not specified
+    - nested replacements where values of replace_vars may be replaced themselves
+
+    Args:
+        string:        Original string
+        replace_vars:  Variables that can be replaced
+        default:       Optional default value used for variables that are not in replace_vars.
+    """
+    matches = re.finditer(r"\{(\w+)(:[^\{\}]*)?\}", string)
+    for match in matches:
+        var = match.group(1)
+        var_expr = match.string[slice(*match.span())]
+        replacement = replace_vars.get(var)
+        if replacement is None:
+            replacement = var_expr if default is None else default  # Default replacements
+        else:
+            replacement = _replace(str(replacement), replace_vars, default)  # Nested replacements
+
+        # Use str.format to handle format specifiers
+        string = string.replace(var_expr, var_expr.format(**{var: replacement}))
+
+    return string
