@@ -44,13 +44,41 @@ class MissingSectionError(MidgardException):
     pass
 
 
+class ParserError(MidgardException):
+    pass
+
+
+class TimerNotRunning(MidgardException):
+    pass
+
+
+class TimerRunning(MidgardException):
+    pass
+
+
+class UnknownConstantError(MidgardException):
+    pass
+
+
+class UnknownConversionError(MidgardException):
+    pass
+
+
 class UnknownEnumError(MidgardException):
     pass
 
 
+class UnknownPackageError(MidgardException):
+    pass
+
+
 class UnknownPluginError(MidgardException):
     pass
 
 
+class UnknownSystemError(MidgardException):
+    pass
+
+
 class UnitError(MidgardException):
     pass
