@@ -389,9 +389,18 @@ class SinexParser(Parser):
         Returns:
             Field converted to datetime object.
         """
-        ce = "19" if int(field[:2]) > 50 else "20"
-        date = datetime.strptime(ce + field[:6].decode(self.file_encoding or "utf-8"), "%Y:%j")
-        time = timedelta(seconds=int(field[7:]))
+        field_str = field.decode(self.file_encoding or "utf-8")
+
+        ce = "19" if int(field_str[:2]) > 50 else "20"
+
+        if field_str != "00:000:00000" and field_str[3:6] == "000":
+            # Doy field may be 000 which does not make sense. Increase value by one
+            year_doy = field_str[:2] + ":"+ "001"
+        else:
+            year_doy = field_str[:6]
+
+        date = datetime.strptime(ce + year_doy, "%Y:%j")
+        time = timedelta(seconds=int(field_str[7:]))
         return date + time
 
     def _convert_exponent(self, field: bytes) -> float:
@@ -1084,10 +1093,17 @@ class SinexParser(Parser):
     parse_solution_normal_equation_matrix = parsing_matrix_factory(
         "SOLUTION/NORMAL_EQUATION_MATRIX", size_marker="SOLUTION/ESTIMATE"
     )
+    
+    
+    #
+    # NOT OFFICIAL SINEX BLOCKS
+    #
 
     @property
-    def discontinuity(self) -> SinexBlock:
-        """Station discontinuities.
+    def solution_discontinuity(self) -> SinexBlock:
+        """Site discontinuities.
+        
+        Note: This is not a official SINEX block.
 
         Example:
             *CODE PT SOLN O __START_TIME __END_TIME__ E __DESCRIPTION
@@ -1107,7 +1123,37 @@ class SinexParser(Parser):
                 SinexField("event_code", 42, "U1"),
                 SinexField("description", 44, "U120"),
             ),
-            parser=self.parse_discontinuity,
+            parser=self.parse_solution_discontinuity,
         )
 
-    parse_discontinuity = parsing_factory()
+    parse_solution_discontinuity = parsing_factory()
+    
+    
+    @property
+    def solution_event(self) -> SinexBlock:
+        """Site events.
+        
+        Note: This is not a official SINEX block.
+
+        Example:
+            *CODE PT SOLN O __START_TIME __END_TIME__ _EVENT   __DESCRIPTION
+             0194  A    1 P 00:000:00000 03:160:00000 CLK ON   Clock steering is used
+                      1111111111222222222233333333334444444444555555555566666666667777777777
+            01234567890123456789012345678901234567890123456789012345678901234567890123456789
+        """
+        return SinexBlock(
+            marker="SOLUTION/EVENT",
+            fields=(
+                SinexField("site_code", 1, "U4"),
+                SinexField("point_code", 6, "U2"),
+                SinexField("soln", 9, "U4"),
+                SinexField("obs_code", 14, "U1"),
+                SinexField("start_time", 16, "O", "epoch"),
+                SinexField("end_time", 29, "O", "epoch"),
+                SinexField("event_code", 42, "U7"),
+                SinexField("description", 51, "U120"),
+            ),
+            parser=self.parse_solution_event,
+        )
+
+    parse_solution_event = parsing_factory()
