@@ -13,6 +13,7 @@ from pathlib import PosixPath
 from typing import Any, Dict, List, Tuple, Union
 
 # External library imports
+import matplotlib as mpl
 from matplotlib.colors import ListedColormap
 from matplotlib.lines import Line2D
 import matplotlib.pyplot as plt
@@ -35,6 +36,8 @@ class MatPlotExt:
 
     | Option             | Value            | Description                                                           |
     |--------------------|------------------|-----------------------------------------------------------------------|
+    | colorbar           | <True|False>     | Plot color bar                                                        |
+    | colorbar_label     | <text>           | Color bar label                                                       |
     | colormap           | <type>           | Color map type for plotting either events or labels (e.g. viridis,    |
     |                    |                  | jet, tab10, rainbow, hsv, plasma)                                     |
     | dpi                | <num>            | Resolution of file in dots per inch                                   |
@@ -44,6 +47,7 @@ class MatPlotExt:
     | elinewidth         | <num>            | Line width of error bar                                               |
     | errorbar           | <True|False>     | Plot error bars, either xerr_array or yerr_array has to be defined    |
     | figsize            | (num, num)       | Figure size given by (width, height) in inches                        |
+    | fontsize           | <num>            | Fontsize of title, axis labels and legend                             |
     | fsize_subtitle     | <num>            | Fontsize of subplot title (statistical information)                   |
     | grid               | <True|False>     | Plot grid                                                             |
     | histogram          | <x, y>           | Plot x-axis histogram on top, y-axis histogram on right or for both   |
@@ -69,9 +73,9 @@ class MatPlotExt:
     |                    |                  | both'.                                                                |
     | title              | <text>           | Main title of subplots                                                |
     | xlabelrotation     | <num>            | Define x-axis label rotation                                          |
-    | xlim               | <[num, num]|     | Define x-axis limit by defining a list with [left, right] range. If       |
-    |                    |  auto|           | xlim=auto, then x-axis limit is automatically chosen and if xlim=        |
-    |                    |  fit_to_data>     | fit_to_data, then x-axis limit is defined related to x-axis data.       | 
+    | xlim               | <[num, num]|     | Define x-axis limit by defining a list with [left, right] range. If   |
+    |                    |  auto|           | xlim=auto, then x-axis limit is automatically chosen and if xlim=     |
+    |                    |  fit_to_data>     | fit_to_data, then x-axis limit is defined related to x-axis data.    | 
     | xticks             | <[num, ...]>     | Define x-axis ticks by defining a list with ticks                     |
     | xticklabels        | <[text, ...]>    | Define x-axis ticks labels by defining a list with labels             |
     | ylim               | <[num, num]>     | Define y-axis limit by defining a list with [bottom, top] range       |
@@ -90,6 +94,8 @@ class MatPlotExt:
         # Default plotting options
         self.options = {
             "alpha": 1,
+            "colorbar": False,
+            "colorlabel": "",
             "colormap": "tab20",
             "dpi": 200,
             "ecapsize": 4,
@@ -127,11 +133,10 @@ class MatPlotExt:
             "yticks": [],
             "yticklabels": [],
         }
-                             
+                                     
         # Update options
         if options:
-            self.set_options(options)
-        
+            self.set_options_and_rcparams(options)       
             
     def get_statistic(
         self,
@@ -189,14 +194,24 @@ class MatPlotExt:
         return stats
 
 
-    def set_options(self, options: Dict[str, Any]) -> None:
-        """Overwrite default plotting options
+    def set_options_and_rcparams(self, options: Dict[str, Any]) -> None:
+        """Overwrite default plotting options and rcParams
         
         Args:
             options:    Plotting options, which can overwrite default definition.
         """
         self.options.update(options)
-    
+
+        # Change fontsize
+        for entry in ["axes.labelsize", "legend.fontsize", "xtick.labelsize", "ytick.labelsize"]:
+            plt.rcParams[entry] = self.options["fontsize"]
+        
+        # Change fontsize of titles
+        for entry in ["axes.titlesize", "figure.titlesize", "legend.title_fontsize"]:
+            plt.rcParams[entry] = self.options["fontsize"] + 2  
+            
+            
+        #plt.rcParams["legend.frameon"] = False
     
     #
     # BAR PLOTS
@@ -245,7 +260,7 @@ class MatPlotExt:
        
         # Overwrite options with argument definition
         if options:
-            self.set_options(options)   
+            self.set_options_and_rcparams(options)   
     
         # Assign to each label a color
         if label in df.columns:
@@ -321,6 +336,8 @@ class MatPlotExt:
     
         | Option             | Value            | Description                                                             |
         |--------------------|------------------|-------------------------------------------------------------------------|
+        | colorbar           | <True|False>     | Plot color bar based on labels                                          |
+        | colorbar_label     | <text>           | Color bar label                                                         |
         | colormap           | <type>           | Color map type for plotting either events or labels (e.g. viridis, jet, |
         |                    |                  | tab10, rainbow, hsv, plasma)                                            |
         | dpi                | <num>            | Resolution of file in dots per inch                                     |
@@ -348,9 +365,9 @@ class MatPlotExt:
         |                    |                  | for x-axis, y-axis or both axis via specifying 'x', 'y' or both'.       |
         | title              | <text>           | Main title of subplots                                                  |
         | xlabelrotation     | <num>            | Define x-axis label rotation                                            |
-        | xlim               | <[num, num]|     | Define x-axis limit by defining a list with [left, right] range. If       |
-        |                    |  auto|           | xlim=auto, then x-axis limit is automatically chosen and if xlim=        |
-        |                    |  fit_to_data>     | fit_to_data, then x-axis limit is defined related to x-axis data.       | 
+        | xlim               | <[num, num]|     | Define x-axis limit by defining a list with [left, right] range. If     |
+        |                    |  auto|           | xlim=auto, then x-axis limit is automatically chosen and if xlim=       |
+        |                    |  fit_to_data>     | fit_to_data, then x-axis limit is defined related to x-axis data.      | 
         | xticks             | <[num, ...]>     | Define x-axis ticks by defining a list with ticks                       |
         | xticklabels        | <[text, ...]>    | Define x-axis ticks labels by defining a list with labels               |
         | ylim               | <[num, num]>     | Define y-axis limit by defining a list with [bottom, top] range         |
@@ -379,12 +396,12 @@ class MatPlotExt:
                            'labels' and 'events' can not be chosen together, either 'labels' or 'events' should be 
                            defined.
         """
-    
+        statistic_data = list()
         cmap = None
 
         # Overwrite options with argument definition
         if options:
-            self.set_options(options)    
+            self.set_options_and_rcparams(options)    
         original_histogram_option = self.options["histogram"]
     
         # Convert x_arrays, y_arrays to list
@@ -416,8 +433,12 @@ class MatPlotExt:
                 colors = [None for ii in range(0, len(y_arrays))]
             else:
                 colors = [cmap(ii) for ii in range(0, len(y_arrays))]
-                
-    
+        
+        # Generate complete array for statistic
+        if self.options["statistic"] and len(y_arrays) > 1:
+            for y_array in y_arrays:
+                statistic_data.extend(list(y_array))
+              
         # Plot several plots depending on number of y-arrays
         for idx, (x_array, y_array, xerr_array, yerr_array, color) in enumerate(zip(x_arrays, y_arrays, xerr_arrays, yerr_arrays, colors)):
     
@@ -430,7 +451,17 @@ class MatPlotExt:
     
             # Plot figure
             self.plot_subplot_row(
-                ax, x_array, y_array, xerr_array, yerr_array, xlabel, ylabel, x_unit=x_unit, y_unit=y_unit, color=color
+                ax, 
+                x_array, 
+                y_array, 
+                xerr_array, 
+                yerr_array, 
+                xlabel, 
+                ylabel, 
+                x_unit=x_unit, 
+                y_unit=y_unit, 
+                color=color,
+                statistic_data=statistic_data
             )
     
             # Plot vertical line for events in plot
@@ -458,7 +489,7 @@ class MatPlotExt:
             self.options["legend_location"] = "bottom" if self.options["legend_location"] == None else self.options["legend_location"]
             self._plot_legend(legend_labels, labels)
     
-        if labels:
+        if labels and not self.options["colorbar"]: # No legend is needed in case of color bar based on labels.
             if self.options["projection"] == "polar":
                 self.options["legend_location"] = "bottom" if self.options["legend_location"] == None else self.options["legend_location"]
             else:
@@ -467,8 +498,23 @@ class MatPlotExt:
             self._plot_legend(legend_labels, labels)
     
         # Rotates and right aligns the x labels, and moves the bottom of the axes up to make room for them
-        if isinstance(x_arrays[0][0], datetime):
-            fig.autofmt_xdate()
+        #if isinstance(x_arrays[0][0], datetime):
+        #    fig.autofmt_xdate()
+        fig.autofmt_xdate()
+                
+        # Generate colorbar of labels
+        # TODO: Does not work correctly. Color of labels and colormap does not fit. See e.g. https://jakevdp.github.io/mpl_tutorial/tutorial_pages/tut3.html
+        if self.options["colorbar"]:
+            fig.colorbar(
+                    mpl.cm.ScalarMappable(
+                            norm=mpl.colors.Normalize(vmin=min(labels), vmax=max(labels)), 
+                            cmap=cmap,
+                    ),
+                    #extend='both', 
+                    #shrink=0.70, 
+                    orientation="vertical",
+                    label=self.options["colorbar_label"],
+            )
     
         # Automatically adjusts subplot params so that the subplot(s) fits in to the figure area
         fig.tight_layout()
@@ -574,7 +620,7 @@ class MatPlotExt:
 
         # Overwrite options with argument definition
         if options:
-            self.set_options(options)  
+            self.set_options_and_rcparams(options)  
     
         # Generate subplot
         fig, axes = plt.subplots(
@@ -644,8 +690,10 @@ class MatPlotExt:
     
             # Plot vertical line for events in each subplot
             if events:
+                linestyle_def = [(0, (5,5)), (2, (5,5)), (4, (5,5)), (6, (5,5)), (8, (5,5))]
                 for idx, (label, entries) in enumerate(sorted(events.items())):
-                    [ax.axvline(x=e, label=label, color=cmap(idx)) for e in entries]
+                    linestyle = linestyle_def[idx] if len(events.keys()) <= len(linestyle_def) else "--"
+                    [ax.axvline(x=e, label=label, linestyle=linestyle, color=cmap(idx)) for e in entries]
     
         # Change tick labelsize
         if self.options["tick_labelsize"]:
@@ -657,7 +705,7 @@ class MatPlotExt:
         # Plot event legend
         if events:
             self.options["legend_location"] = "bottom" if self.options["legend_location"] == None else self.options["legend_location"]
-            self._plot_legend(legend_labels, labels=events.keys())
+            self._plot_legend(legend_labels, labels=sorted(events.keys()))
     
         # Rotates and right aligns the x labels, and moves the bottom of the axes up to make room for them
         if isinstance(x_array[0], datetime):
@@ -695,6 +743,7 @@ class MatPlotExt:
         label: str = "",
         color: Union[None, np.ndarray] = None,
         subtitle: List[str] = [],
+        statistic_data: List[float] = list(),
         options: Dict[str, Any] = None,
     ) -> None:
         """Generate single row of plot subplot
@@ -745,13 +794,14 @@ class MatPlotExt:
            label:          Legend label.
            color:          Marker color.
            subtitle:       List with element of subplot title.
+           statistic_data: Complete set of y-array data in case of statistic is needed for a plot based on len(y_arrays) > 0
            options:        Dictionary with options, which overwrite default plot configuration.
         """
         subtitle = subtitle.copy()
         
         # Overwrite options with argument definition
         if options:
-            self.set_options(options)  
+            self.set_options_and_rcparams(options)  
     
         if self.options["plot_type"] == "scatter":
             import matplotlib
@@ -876,7 +926,13 @@ class MatPlotExt:
     
         # Plot statistical text line as title over each subplot
         if self.options["statistic"]:
-            subtitle.extend(self.get_statistic(y_array, self.options["statistic"], y_unit))
+            subtitle.extend(
+                self.get_statistic(
+                        statistic_data if statistic_data else y_array, 
+                        self.options["statistic"], 
+                        y_unit,
+                )
+            )
     
         # Plot subtitle of current row
         if subtitle:
@@ -915,7 +971,7 @@ class MatPlotExt:
        
         # Overwrite options with argument definition
         if options:
-            self.set_options(options) 
+            self.set_options_and_rcparams(options) 
     
         histogram = self.options["histogram"].replace(",", " ").split()
     
