@@ -4,12 +4,12 @@ Description:
 ------------
 This module is divided into three different types of classes:
 
-    1. Main class SiteCoord that provides basic functionality to the user. See examples
+    1. Main class SiteCoord provides basic functionality to the user. See exampless
     2. Site coordinate source type classes:
-        - There is one class for each source type
+        - There is one class for each source type.
         - A class with all relevant site coordinate information for a point in time.
     3. Site coordinate history source type classes:
-        - There is one class for each source type
+        - There is one class for each source type.
         - Converts input from source_data to a object of type SiteCoordHistorySinex, etc and provides functions
           for accessing the history and relevant dates. 
         - The history consist of a time interval for which the entry is valid and an instance of a site coordinate 
@@ -22,6 +22,7 @@ Example:
     
     from midgard import parsers
     from midgard.site_info.site_coord import SiteCoord
+    from datetime import datetime
 
     # Read SINEX data    
     p = parsers.parse_file(parser_name='sinex_site', file_path='./data/site_info/igs.snx')
@@ -227,11 +228,6 @@ class SiteCoordSinex(SiteInfoBase):
     source: str = "snx"
     fields: Dict = dict()
 
-
-    #
-    # GET METHODS
-    #
-
     @property
     def date_from(self) -> datetime:
         """ Get site coordinate starting date from site information attribute
@@ -454,7 +450,7 @@ class SiteCoordHistorySsc(SiteInfoHistoryBase):
             source_data:  Source data with site information.
 
         Returns:
-            Dictionary with (date_from, date_to) tuple as key. The values are SiteCoordSinex objects.
+            Dictionary with (date_from, date_to) tuple as key. The values are SiteCoordSsc objects.
         """
         if self.station in source_data:
             raw_info = source_data[self.station]
@@ -636,9 +632,9 @@ class SiteCoordSsc(SiteInfoBase):
             Standard deviation of site coordinate for X, Y and Z in [m]
         """
         return np.array([
-                        self._info["sigma_X"],
-                        self._info["sigma_Y"],
-                        self._info["sigma_Z"],                
+                        self._info["sigma_x"],
+                        self._info["sigma_y"],
+                        self._info["sigma_z"],                
         ])
 
     @property
@@ -737,9 +733,9 @@ class SiteCoordSsc(SiteInfoBase):
         Args:
             pos_sigma: Standard deviation of site coordinate for X, Y and Z in [m]
         """
-        self._info["sigma_X"] = pos_sigma[0]
-        self._info["sigma_Y"] = pos_sigma[1]
-        self._info["sigma_Z"] = pos_sigma[2]                
+        self._info["sigma_x"] = pos_sigma[0]
+        self._info["sigma_y"] = pos_sigma[1]
+        self._info["sigma_z"] = pos_sigma[2]                
 
 
     def set_ref_epoch(self, ref_epoch: datetime) -> None:
