@@ -84,6 +84,8 @@ def dset_full():
     _dset.add_sigma("numbers2", val=[3, 3, 3, 3, 3], sigma=[0.2, 0.2, 0.2, 0.2, 0.2])
     _dset.add_text("text", val=["aaa", "aaa", "aaa", "aaa", "aaa"])
     _dset.add_time("time", val=[datetime(2015, 1, i) for i in range(5, 10)], scale="utc", fmt="datetime")
+    # TODO: will fail when trying to merge or extend with dset_empty. How to handle empty datetime values?
+    #_dset.add_time("time_gps", val=np.asarray([[2205, 875600 + i, 1] for i in range(5)]), scale="gps", fmt="gps_ws")
     _dset.add_time_delta("time_delta", val=[timedelta(seconds=i) for i in range(20, 25)], scale="utc", fmt="timedelta")
 
     # Collections
@@ -200,6 +202,13 @@ def test_subset_2(dset_full):
         test_field(field, dset_full.num_obs)
 
 
+@pytest.mark.parametrize("dset", (dset_empty, dset_float, dset_full, dset_no_collection), indirect=True)
+def test_subset_3(dset):
+    """Test subset which removes all data"""
+    idx = np.zeros(dset.num_obs, dtype=bool)
+    dset.subset(idx)
+    assert dset.num_obs == 0
+
 @pytest.mark.parametrize(
     "dset1, dset2",
     [
@@ -729,3 +738,17 @@ def test_delete(dset_full):
         dset_full.numbers_1
     with pytest.raises(AttributeError):
         dset_full.numbers_2
+
+@pytest.mark.parametrize("type_", [
+    (datetime.now()),
+    ((datetime.now(),)),
+    ({"b": datetime.now()}),
+    ([[[[datetime.now()]]]]),
+])
+def dset_meta_error_msg(type_):
+    # Too complex datatype is being saved to meta and should give error message
+
+    _dset = dataset.Dataset()
+    _dset.meta.add("a", type_)
+    with pytest.raises(TypeError):
+        _dset.write("test.hdf5")
